<!-- Signup form -->
<form class="form-horizontal ajax-post" role="form" action="{% url 'rest_verify_email' %}">{% csrf_token %}
  <div class="form-group">
    <label for="key" class="col-sm-2 control-label">Key</label>
    <div class="col-sm-10">
      <input name="key" type="text" class="form-control" id="key" placeholder="Key">
      <p class="help-block">Put here a key which was sent in verification email</p>
    </div>
  </div>

  <div class="form-group">
    <div class="col-sm-offset-2 col-sm-10">
      <button type="submit" class="btn btn-default">Verify</button>
    </div>
  </div>

  <div class="form-group api-response"></div>
</form>
