{% extends "base.html" %}

{% block content %}
  <div class="row">
    <h3>Resend E-mail verification</h3><hr/>
    {% include "fragments/resend_email_verification_form.html" %}
  </div>
{% endblock %}
